Changelog
=========

.. You should *NOT* be adding new change log entries to this file, this
   file is managed by towncrier. You *may* edit previous change logs to
   fix problems like typo corrections or such.

.. towncrier release notes start

1.0.0 (2021-06-10)
------------------

Breaking changes:


- Move from Recaptcha to Hcaptcha, using different api and captcha service provider [andreasma]
  Remove compatibility with Python 2 and Plone versions minor to 5.2 [andreasma] (#30)


1.0.0 (unreleased)
------------------

- Initial release. [andreasma]
